//----------------------------------------------------------------------
// Database.java
// Author: Bob Dondero
//----------------------------------------------------------------------

package edu.princeton.penny;

import java.sql.DriverManager;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import org.sqlite.SQLiteConfig;
import java.util.ArrayList;
import java.io.File;
import java.net.URL;

public class Database
{
   private static final String DATABASE_FILE = "penny.sqlite";

   public static ArrayList<Book> getBooks(String author)
      throws Exception
   {
      ClassLoader classLoader = Database.class.getClassLoader();
      URL resource = classLoader.getResource(DATABASE_FILE);
      if (resource == null)
         throw new Exception("Database connection failed");
      String fileName = resource.getFile();

      SQLiteConfig config = new SQLiteConfig();
      config.setReadOnly(true);
      Connection connection =
         DriverManager.getConnection("jdbc:sqlite:" + fileName,
            config.toProperties());

      try
      {
         ArrayList<Book> result = new ArrayList<Book>();

         PreparedStatement statement = connection.prepareStatement(
            "SELECT isbn, author, title FROM books "
            + "WHERE author LIKE ?");
         statement.setString(1, author + "%");
         ResultSet resultSet = statement.executeQuery();

         while (resultSet.next())
         {
            String isbn = resultSet.getString("isbn");
            String foundAuthor = resultSet.getString("author");
            String title = resultSet.getString("title");
            Book book = new Book(isbn, foundAuthor, title);
            result.add(book);
         }

         return result;
      }
      finally
      {
         connection.close();
      }
   }
}
