//----------------------------------------------------------------------
// SearchResultsServlet.java
// Author: Bob Dondero
//----------------------------------------------------------------------

package edu.princeton.penny;

import java.io.PrintWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.net.URLEncoder;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.Cookie;
import org.apache.commons.text.StringEscapeUtils;

public class SearchResultsServlet extends HttpServlet
{
   protected void doGet(HttpServletRequest request,
      HttpServletResponse response)
      throws ServletException, IOException
   {
      String prevAuthor;
      ArrayList<Book> books;

      String author = request.getParameter("author");
      if (author == null)
         author = "";
      author = author.trim();

      if (author.equals(""))
      {
         prevAuthor = "(None)";
         books = new ArrayList<Book>();
      }
      else
      {
         prevAuthor = author;
         try
         {
            books = Database.getBooks(author);
         }
         catch (Exception e)
         {
            response.setContentType("text/html");
            response.getWriter().println(e.toString());
            return;
         }
      }

      String safeAuthor = URLEncoder.encode(prevAuthor, "UTF-8");
      response.addCookie(new Cookie("prevAuthor", safeAuthor));

      response.setContentType("text/html; charset=utf-8");
      PrintWriter pw = response.getWriter();

      pw.println("<!DOCTYPE html>");
      pw.println("<html>");
      pw.println("<head>");
      pw.println("<title>Penny.com</title>");
      pw.println("</head>");
      pw.println("<body>");
      pw.println(Common.getHeader());
      pw.println("<h1>Author Search Results</h1>");
      pw.println("<h2>Books by ");
      pw.println(StringEscapeUtils.escapeHtml4(prevAuthor));
      pw.println(":</h2>");

      if (books.size() == 0)
         pw.println("(None)<br>");
      else
         for (Book book : books)
            pw.println(
               StringEscapeUtils.escapeHtml4(book.getIsbn())
               + ": "
               + "<strong>"
               + StringEscapeUtils.escapeHtml4(book.getAuthor())
               + "</strong>: "
               + StringEscapeUtils.escapeHtml4(book.getTitle())
               + "<br>");

      pw.println("<br>");
      pw.println("<br>");
      pw.println("Click here to do another ");
      pw.println("<a href=\"/searchform\">author search</a>.");
      pw.println("<br>");
      pw.println("<br>");
      pw.println("<br>");
      pw.println("<br>");
      pw.println(Common.getFooter());
      pw.println("</body>");
      pw.println("</html>");
   }
}
