package edu.princeton.penny;

import java.util.ArrayList;
import java.util.Date;
import java.util.Calendar;
import java.util.Map;
import java.text.DateFormat;
import java.net.URLEncoder;
import java.net.URLDecoder;
import java.io.UnsupportedEncodingException;

import jakarta.servlet.http.Cookie;
import jakarta.servlet.http.HttpServletResponse;

import org.apache.commons.text.StringEscapeUtils;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.CookieValue;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;

//----------------------------------------------------------------------

@RestController
public class PennyController {

   private static String getAmPm()
   {
      if (Calendar.getInstance().get(Calendar.AM_PM) == Calendar.AM)
         return "morning";
      return "afternoon";
   }

   private static String getCurrentTime()
   {
      DateFormat df = DateFormat.getDateInstance(DateFormat.FULL);
      return df.format(new Date());
   }

   @GetMapping("/")
   public ModelAndView index(Map<String, Object> model)
   {
      model.put("ampm", getAmPm());
      model.put("currentTime", getCurrentTime());
      return new ModelAndView("index", model);
   }

   @GetMapping("/searchform")
   public ModelAndView searchForm(Map<String, Object> model,
      @CookieValue(value="prevAuthor", defaultValue="(None)")
      String prevAuthor)
   {
      prevAuthor = URLDecoder.decode(prevAuthor);

      model.put("ampm", getAmPm());
      model.put("currentTime", getCurrentTime());
      model.put("author", prevAuthor);
      return new ModelAndView("searchform", model);
   }

   @GetMapping("/searchresults")
   public ModelAndView searchResults(Map<String, Object> model,
      @RequestParam(defaultValue="") String author,
      HttpServletResponse res)
      throws UnsupportedEncodingException
   {
      String prevAuthor;
      ArrayList<Book> books = new ArrayList<Book>();

      author = author.trim();

      if (author.equals(""))
      {
         prevAuthor = "(None)";
      }
      else
      {
         prevAuthor = author;
         try
         {
            books = Database.getBooks(author);
         }
         catch (Exception e)
         {
            // Ignore database errors.
         }
      }

      String safeAuthor = URLEncoder.encode(prevAuthor, "UTF-8");
      Cookie cookie = new Cookie("prevAuthor", safeAuthor);
      res.addCookie(cookie);

      model.put("ampm", getAmPm());
      model.put("currentTime", getCurrentTime());
      model.put("author", prevAuthor);
      model.put("books", books);
      return new ModelAndView("searchresults", model);
   }
}
